BondingData

Struct BondingData 

pub struct BondingData {
    pub identifier: Option<PeerId>,
    pub local_address: Option<Address>,
    pub name: Option<String>,
    pub address: Option<Address>,
    pub le_bond: Option<LeBondData>,
    pub bredr_bond: Option<BredrBondData>,
    pub device_class: Option<DeviceClass>,
    /* private fields */
}
Represents the bonding data for a single peer.

Fields

identifier: Option<PeerId>

The identifier that uniquely identifies this peer.

local_address: Option<Address>

The local Bluetooth identity address that this bond is associated with.

name: Option<String>

The name of the peer, if known.

address: Option<Address>

The identity address of the peer.

le_bond: Option<LeBondData>

Bonding data that is present when this peer is paired on the LE transport.

bredr_bond: Option<BredrBondData>

Bonding data that is present when this peer is paired on the BR/EDR transport.

device_class: Option<DeviceClass>

The device class of the peer, if known.