HostData

Struct HostData 

pub struct HostData {
    pub irk: Option<Key>,
    /* private fields */
}
Represents persistent local host data.

Fields

irk: Option<Key>

The local Identity Resolving Key used by a bt-host device to generate Resolvable Private Addresses when privacy is enabled.

May be absent for hosts that do not use LE privacy, or that only use Non-Resolvable Private Addresses.

NOTE: This key is distributed to LE peers during pairing procedures. The client must take care to assign an IRK that consistent with the local bt-host identity.