HostInfo

Struct HostInfo 

pub struct HostInfo {
    pub id: Option<HostId>,
    pub technology: Option<TechnologyType>,
    pub active: Option<bool>,
    pub local_name: Option<String>,
    pub discoverable: Option<bool>,
    pub discovering: Option<bool>,
    pub addresses: Option<Vec<Address>>,
    /* private fields */
}
Information about a Bluetooth controller and its associated host-subsystem state.

Fields

id: Option<HostId>

Uniquely identifies a host on the current system.

This field is always present.

technology: Option<TechnologyType>

The Bluetooth technologies that are supported by this adapter.

This field is always present.

active: Option<bool>

Indicates whether or not this is the active host. The system has one active host which handles all Bluetooth procedures.

local_name: Option<String>

The local name of this host. This is the name that is visible to other devices when this host is in the discoverable mode.

discoverable: Option<bool>

Whether or not the local adapter is currently discoverable over BR/EDR and LE physical channels.

discovering: Option<bool>

Whether or not device discovery is currently being performed.

addresses: Option<Vec<Address>>

The addresses (LE and/or BR/EDR) associated with the host.

The Public address is always reported first.

This field is always present.