LeBondData

Struct LeBondData 

pub struct LeBondData {
    pub connection_parameters: Option<LeConnectionParameters>,
    pub services: Option<Vec<Uuid>>,
    pub irk: Option<PeerKey>,
    pub csrk: Option<PeerKey>,
    pub peer_ltk: Option<Ltk>,
    pub local_ltk: Option<Ltk>,
    /* private fields */
}

Fields

connection_parameters: Option<LeConnectionParameters>

The peer’s preferred connection parameters, if known.

services: Option<Vec<Uuid>>

Known GATT service UUIDs.

irk: Option<PeerKey>

Identity Resolving RemoteKey used to generate and resolve random addresses.

csrk: Option<PeerKey>

Connection Signature Resolving RemoteKey used for data signing without encryption.

peer_ltk: Option<Ltk>

LE long-term key used to encrypt a connection when the peer is in the LE Peripheral role.

In legacy pairing (peer_ltk.security.secure_connections is false), this key corresponds to the key distributed by the peer. In Secure Connections pairing there is only one LTK and peer_ltk is the same as local_ltk.

local_ltk: Option<Ltk>

LE long-term key used to encrypt a connection when the peer is in the LE Central role.

In legacy pairing (local_ltk.security.secure_connections is false), this key corresponds to the key distributed by the local device. In Secure Connections pairing there is only one LTK and local_ltk is the same as peer_ltk.