Peer

Struct Peer 

pub struct Peer {
Show 13 fields pub id: Option<PeerId>, pub address: Option<Address>, pub technology: Option<TechnologyType>, pub connected: Option<bool>, pub bonded: Option<bool>, pub name: Option<String>, pub appearance: Option<Appearance>, pub device_class: Option<DeviceClass>, pub rssi: Option<i8>, pub tx_power: Option<i8>, pub services: Option<Vec<Uuid>>, pub le_services: Option<Vec<Uuid>>, pub bredr_services: Option<Vec<Uuid>>, /* private fields */
}
Represents a remote BR/EDR, LE, or dual-mode BR/EDR/LE peer.

Fields

id: Option<PeerId>

Uniquely identifies this peer on the current system.

This field is always present.

address: Option<Address>

Bluetooth device address that identifies this peer. Clients should display this field to the user when name is not available.

This field is always present.

NOTE: Clients should use the identifier field to keep track of peers instead of their address.

technology: Option<TechnologyType>

The Bluetooth technologies that are supported by this peer.

This field is always present.

connected: Option<bool>

Whether or not a BR/EDR and/or LE connection exists to this peer.

This field is always present.

bonded: Option<bool>

Whether or not this peer is bonded.

This field is always present.

name: Option<String>

The name of the peer, if known.

appearance: Option<Appearance>

The LE appearance property. Present if this peer supports LE and the appearance information was obtained over advertising and/or GATT.

device_class: Option<DeviceClass>

The class of device for this device, if known.

rssi: Option<i8>

The most recently obtained advertising signal strength for this peer. Present if known.

tx_power: Option<i8>

The most recently obtained transmission power for this peer. Present if known.

services: Option<Vec<Uuid>>

The list of service UUIDs known to be available on this peer.

This is a legacy field that should not be depended on for new code.

le_services: Option<Vec<Uuid>>

The list of service UUIDs known to be available on the LE transport.

Never present if technology is CLASSIC.

bredr_services: Option<Vec<Uuid>>

The cached list of service UUIDs previously discovered on the BR/EDR transport. Services are not removed if peer is disconnected if subsequent searches don’t find them.

Never present if technology is LOW_ENERGY.

This is a legacy field that should not be depended on for new code.